<template>
  <div>
    <el-dialog :title="`${title}关联设备`" :visible="visible" v-if="visible" width="70%" top="8vh"
      :before-close="handleClose">
      <div class="tree-table-container">
        <el-row class="fullheight" :gutter="20">
          <el-col :span="6" class="fullheight">
            <div class="common-tree-container">
              <div class="common-tree-title">
                <i class="el-icon-menu"></i> 设备分类目录
              </div>
              <div class="common-tree-content">
                <el-tree highlight-current v-if="treeData.length" :data="treeData" :props="defaultProps"
                  @node-click="handleNodeClick" default-expand-all :expand-on-click-node="false">
                  <span class="custom-tree-node" slot-scope="{data}">{{
                    data.name
                  }}</span>
                </el-tree>
              </div>
            </div>
          </el-col>
          <el-col :span="18" class="fullheight">
            <div class="common-table-container">
              <div class="bbsl-common-page">
                <!-- <div class="bbsl-table-search"></div> -->
                <div class="bbsl-table-content" ref="contentPanel">
                  <div class="bbsl-btn-content" ref="btnPanel"></div>
                  <el-table :row-key="getRowKey" ref="multipleTable" :data="tableData.filter(
                    (data) =>
                      !search ||
                      data.name.toLowerCase().includes(search.toLowerCase())
                  )
                    " @selection-change="handleSelectionChange" height="56vh">
                    <el-table-column type="selection" :reserve-selection="true" width="55">
                    </el-table-column>
                    <el-table-column label="请选择设备" prop="name">
                      <template #header>
                        <div class="table-header">
                          <div class="left">请选择设备</div>
                          <div class="left">
                            <el-input v-model="search" size="mini" clearable placeholder="输入关键字搜索" />
                          </div>
                        </div>
                      </template>
                      <!-- <template #default="scope">
                        <div>{{ scope.row.name }}({{ scope.row.code }})</div>
                      </template> -->
                    </el-table-column>
                    <!-- <el-table-column align="right">
                      <template slot="header">
                        <el-input v-model="search" size="mini" clearable placeholder="输入关键字搜索" />
                      </template>
                    </el-table-column> -->
                  </el-table>
                  <el-pagination align="right" background class="bbsl-pagination" ref="paginationPanel"
                    @size-change="handleSizeChange" @current-change="handleCurrentChange"
                    :current-page="queryParam.pageBean.page" :page-sizes="[20, 30, 40, 50]"
                    :page-size="queryParam.pageBean.pageSize" layout="total, sizes, prev, pager, next, jumper"
                    :total="total"></el-pagination>
                </div>
              </div>
            </div>
          </el-col>
        </el-row>
      </div>
      <span slot="footer" class="dialog-footer">
        <el-button type="primary" @click="goInfo">关 联</el-button>
        <el-button @click="handleClose">取 消</el-button>
      </span>
    </el-dialog>
  </div>
</template>
<script>
import relationContract from '@/api/device/relationContract.js'
import utils from '@/hotent-ui-util.js'
import { TableMixin } from '@/mixins/tableMixin'

export default {
  name: 'relatedEquimentInfoDialog',
  components: {},
  mixins: [TableMixin],
  data() {
    return {
      // 设备分类树
      treeNode: { code: '', id: '0', name: '设备分类', type: 0, children: [] },
      treeData: [{ code: '', id: '0', name: '设备分类', type: 0, children: [] }],
      defaultProps: {
        children: 'children',
        label: 'name'
      },
      visible: false,
      title: '新增',
      params: {
        contractId: '',
        proTypeCode: ''
      },
      querys: [
        {
          group: 'main',
          operation: 'EQUAL',
          parentGroup: '',
          property: 'tab.deviceTypeCode',
          relation: 'AND',
          value: ''
        }
      ],
      relationList: {
        contractId: '',
        deviceList: []
      },
      loading: false,
      multipleSelection: [], // 复选框
      tableData: [],
      data: [],
      search: '',
      total: 0, // 总条目数
      parameters: {} //接收参数
    }
  },
  created() {
  },
  mounted() {
    this.getTreen()
  },
  methods: {
    handleNodeClick(data) {
      this.treeNode = data
      if (data.id == '0') {
        this.queryParam.params.proTypeCode = this.treeNode.code
        this.getloadData(1)
      } else {
        this.queryParam.params.proTypeCode = this.treeNode.code
        this.getloadData(1)
      }
    },
    // 设备组织树查询
    getTreen() {
      relationContract.AllproductType({ id: '0' }).then((res) => {
        this.treeData[0].children = res.value
        this.$set(this.treeData)
      })
    },
    edit(row) {
      this.visible = true
      this.params.contractId = row.id
      this.relationList.contractId = row.id
      this.getloadData(1)
    },
    getloadData(page) {
      if (page) {
        this.queryParam.pageBean.page = page
      }
      this.loading = true
      this.tableData = []
      this.queryParam.params = this.params
      console.log(this.queryParam)
      relationContract.getDeviceList(this.queryParam, (res) => {
        this.total = res.total
        this.tableData = res.rows
        this.$set(this.tableData)
        this.loading = false
      })
    },
    loadData() {
    },
    handleSelectionChange(val) {
      this.multipleSelection = val
      console.log(this.multipleSelection)
    },
    // 指定一个key标识这一行的数据
    getRowKey(row) {
      return row.id
    },
    // 保存
    goInfo() {
      this.relationList.deviceList = this.multipleSelection
      let methods
      if (this.title == '新增') {
        methods = relationContract.save
        methods(this.relationList, (res) => {
          if (res.state) {
            this.$notify({
              type: 'success',
              message: '关联成功',
              duration: 2000
            })
            this.handleClose()
            this.$parent.loadData(1)
          }
        })
      }
    },
    handleClose() {
      this.$refs.multipleTable.clearSelection()
      this.search = ''
      this.title = '新增'
      this.visible = false
    },
    handleSizeChange(val) {
      this.queryParam.pageBean.pageSize = val
      this.getloadData()
    },
    handleCurrentChange(val) {
      this.queryParam.pageBean.page = val
      this.getloadData()
    }
  }
}
</script>
<style lang="scss" scoped>
.table-header {
  display: flex;
  justify-content: space-between;
  align-items: center;
}
::v-deep .el-pagination {
  position: relative;
  top: 5px;
}

.bbsl-table-content {
  margin-top: 0% !important;
}

.common-tree-container ::v-deep .el-tree {
  border: none;
}

.tree-table-container .common-tree-container {
  height: 65vh !important;
}

.tree-table-container .common-tree-container {
  box-shadow: none;
}
</style>
